@@ -33,7 +33,7 @@ import os
 import sys
 import traceback
 
-VERSION='0.25'
+VERSION='0.26'
 
 def lint(args):
     logger = getLogger(__name__)
@@ -122,10 +122,10 @@ def main():
                         action='version',
                         version=u"%(prog)s {}".format(VERSION),
                         help=u'Show version and exit.')
-    parser_lint.add_argument('-u', '--unacceptable_level',
-                             action='store',
-                             default='CRITICAL',
-                             help=(u'Error level that aborts the check.'))
+    parser.add_argument('-u', '--unacceptable_level',
+                        action='store',
+                        default='CRITICAL',
+                        help=(u'Error level that aborts the check.'))
     args = parser.parse_args()
     lint(args)
 
